High level API
==============

.. autoclass:: sipua.Application
   :members:

.. autoclass:: sipua.Call()
   :members:
   :inherited-members:
   :exclude-members: create_request, create_response, handle_request, send_request, send_response
